import { default as React, PropsWithChildren } from 'react';

/**
 * Global state modifiers functions.
 */
export declare class GlobalStateReducers<S> {
    /**
     * The current state (readonly).
     * @protected
     */
    protected state: Readonly<S>;
    /**
     * State update system.
     * @private
     */
    private stateUpdater;
    /**
     * Assign changes to the current state.
     * @param stateUpdate Changes to apply to the current state.
     */
    setState(stateUpdate: Partial<S>): void;
}
/**
 * Main global state class.
 */
export declare class GlobalState<S, R extends GlobalStateReducers<S>> {
    protected defaultValue: S;
    protected reducers: R;
    /**
     * Global state context.
     * @protected
     */
    protected context: React.Context<S>;
    /**
     * State update system, used in the reducers class.
     * @protected
     */
    protected stateUpdater: React.Dispatch<S>;
    /**
     * Create a new global state.
     * @param defaultValue The default value of the global state.
     * @param reducers Reducers class.
     */
    constructor(defaultValue: S, reducers: R);
    /**
     * Get the context for the global state.
     */
    getContext(): React.Context<S>;
    /**
     * Get the default value of the global state.
     */
    getDefaultValue(): S;
    /**
     * Assign the state update system, used in the reducers class.
     * @param updater State update system instance.
     */
    setStateUpdater(updater: React.Dispatch<S>): void;
    /**
     * Get the configured state reducers class for the current state.
     * @param state The state on which the reducers should apply.
     */
    getStateReducers(state: S): R;
}
/**
 * Global state Provider hook.
 * @param globalState Global state for which to get the global state Provider.
 */
export declare function useGlobalStateProvider<S, R extends GlobalStateReducers<S>>(globalState: GlobalState<S, R>): React.FunctionComponent<PropsWithChildren<{}>>;
/**
 * Global state Provider component
 * @constructor
 */
export declare function GlobalStateProvider<S, R extends GlobalStateReducers<S>>({ globalState, children }: React.PropsWithChildren<{
    /**
     * Global state for which to get the global state Provider.
     */
    globalState: GlobalState<S, R>;
}>): React.JSX.Element;
/**
 * Get the global state and its reducers.
 * @param globalState The global state to get.
 */
export declare function useGlobalState<S, R extends GlobalStateReducers<S>>(globalState: GlobalState<S, R>): [S, R];
/**
 * Get the reducers of the global state.
 * @param globalState The global state for which to get the reducers.
 */
export declare function useGlobalStateReducers<S, R extends GlobalStateReducers<S>>(globalState: GlobalState<S, R>): R;
/**
 * Get the global state data.
 * @param globalState The global state for which to get the data.
 */
export declare function useGlobalStateValue<S, R extends GlobalStateReducers<S>>(globalState: GlobalState<S, R>): S;
